from pydantic_settings import BaseSettings, SettingsConfigDict

from src.core.common.constants import PydanticEnvPrefixEnum, EnvFileLocation, EnvironmentEnum

from src.core.settings.database import DatabaseSettings
from src.core.settings.groq import GroqSettings


class Settings(BaseSettings):
    model_config = SettingsConfigDict(
        case_sensitive=True,
        env_nested_delimiter='__',
        env_prefix=PydanticEnvPrefixEnum.APP.value,
        env_file=(
            EnvFileLocation.PRODUCTION,
            EnvFileLocation.TESTING,
        )
    )

    MODE: EnvironmentEnum

    POSTGRES: DatabaseSettings
    GROQ: GroqSettings


settings = Settings() # type:ignore